@@ -24,6 +24,11 @@ ETHERNET_STATUS = 'ethernetStatus'
 CELLULAR_STATUS = 'cellularStatus'
 CO2 = 'co2'
 PRESSURE = 'pressure'
+EVENT_TYPES = [
+    TOUCH, TEMPERATURE, OBJECT_PRESENT, HUMIDITY, OBJECT_PRESENT_COUNT,
+    TOUCH_COUNT, WATER_PRESENT, NETWORK_STATUS, BATTERY_STATUS, LABELS_CHANGED,
+    CONNECTION_STATUS, ETHERNET_STATUS, CELLULAR_STATUS, CO2, PRESSURE,
+]
 
 
 class _EventData(dtoutputs.OutputBase):
